@@ -180,7 +180,6 @@ function setUpLegendTooltips() {
             $(this).tooltip({
                 position: 'center right',
                 effect: 'fade',
-                offset: [0, 10],
                 onShow: function () {
                     var offset, pixels_below_screen;
                     // Too high?
@@ -205,6 +204,8 @@ function setUpLegendTooltips() {
 }
 
 
+
+
 /*
 Empty the temp workspace
 */
@@ -267,6 +268,80 @@ function popup_hover_handler(x, y, map) {
 }
 
 
+function legend_action_reload(event) {
+    // send all legend properties to server and reload page
+    var $form, url, name;
+    event.preventDefault();
+    $form = $(this).parents("form.legend-options");
+    url = $form.attr("data-url");
+    $.post(
+        url,
+        $form.serialize(),
+        function () {
+            // Reload page after posting.
+            location.reload();
+        });
+}
+
+
+function setUpLegendColorPickers() {
+    var submit, beforeshow;
+    submit = function (hsb, hex, rgb, el) {
+	    $(el).val(hex);
+	    $(el).ColorPickerHide();
+    };
+    beforeshow = function () {
+        $(this).ColorPickerSetColor(this.value);
+    };
+
+    $("input[name=min_color]").ColorPicker({onSubmit: submit, onBeforeShow: beforeshow});
+    $("input[name=max_color]").ColorPicker({onSubmit: submit, onBeforeShow: beforeshow});
+    $("input[name=too_low_color]").ColorPicker({onSubmit: submit, onBeforeShow: beforeshow});
+    $("input[name=too_high_color]").ColorPicker({onSubmit: submit, onBeforeShow: beforeshow});
+
+    // Setup widget colors.
+    $("#colorSelector").each(function () {
+        var div, rel, color;
+        rel = $(this).attr("rel");
+        color = $(rel).attr("value");
+        div = $(this).find("div");
+        div.css('backgroundColor', '#' + color);
+    });
+
+    // Make the widget clickable.
+    $("#colorSelector").ColorPicker({
+        onBeforeShow: function () {
+            var rel, color;
+            rel = $(this).attr("rel");
+            color = $(rel).attr("value");
+            $(this).ColorPickerSetColor(color);
+        },
+        onChange: function (hsb, hex, rgb) {
+            $("#colorSelector div").css('backgroundColor', '#' + hex);
+        },
+        onSubmit: function (hsb, hex, rgb, el) {
+            var rel;
+            rel = $(el).attr("rel");
+            $(rel).val(hex);
+            $(el).ColorPickerHide();
+        }
+    });
+
+}
+
+
+function setUpLegendEdit() {
+    $(".legend-edit").live("mouseover", function () {
+        if (!$(this).data("popup-initialized")) {
+            $(this).data("popup-initialized", true);
+            $(this).overlay();
+            setUpLegendColorPickers();
+        }
+    });
+    $(".legend-action-reload").live("click", legend_action_reload);
+}
+
+
 // Initialize all workspace actions.
 $(document).ready(function () {
     setUpWorkspaceAcceptable();
@@ -276,7 +351,10 @@ $(document).ready(function () {
     setUpEmptyTempInteraction();
     setUpAnimationSlider();
     setUpGraphEditPopup();
-    setUpLegendTooltips();
+
+    // Set up legend.
+    setUpLegendTooltips(); // The edit function is on the tooltip.
+    setUpLegendEdit();
 
     /* Workspace functions, requires jquery.workspace.js */
     $(".workspace").workspaceInteraction();
