@@ -27,6 +27,8 @@ from lizard_map.workspace import WorkspaceManager
 
 # Workspace stuff
 
+CUSTOM_LEGENDS = 'custom_legends'
+
 
 def workspace(request,
               workspace_id,
@@ -141,21 +143,6 @@ def workspace_item_edit(request, workspace_item_id=None, visible=None):
 def snippet_group_graph_edit(request, snippet_group_id):
     """Edits snippet_group properties using post.
     """
-    restrict_to_month_lookup = {
-        'no-restriction': None,
-        'januari': 1,
-        'februari': 2,
-        'march': 3,
-        'april': 4,
-        'may': 5,
-        'june': 6,
-        'july': 7,
-        'august': 8,
-        'september': 9,
-        'october': 10,
-        'november': 11,
-        'december': 12}
-
     post = request.POST
     title = post.get('title', None)
     x_label = post.get('x_label', None)
@@ -165,8 +152,11 @@ def snippet_group_graph_edit(request, snippet_group_id):
     boundary_value = post.get('boundary_value', None)
     percentile_value = post.get('percentile_value', None)
     aggregation_period = post.get('aggregation_period', None)
-    restrict_to_month = restrict_to_month_lookup[
-        post.get('restrict_to_month', 'no-restriction')]
+    restrict_to_month = post.get('restrict_to_month', None)
+    try:
+        restrict_to_month = int(restrict_to_month)
+    except ValueError:
+        restrict_to_month = None
 
     snippet_group = WorkspaceCollageSnippetGroup.objects.get(
         pk=snippet_group_id)
@@ -590,6 +580,43 @@ def snippet_edit(request, snippet_id):
     return HttpResponse('')
 
 
+def legend_edit(request):
+    """Updates a session legend.
+
+    POST parameters:
+    name
+    min_value (optional)
+    max_value (optional)
+    steps (optional)
+    min_color (optional): format ...
+    max_color (optional)
+    too_low_color (optional)
+    too_high_color (optional)
+
+    request['session']['custom_legends'][<name>] = {..}
+    """
+
+    # Get new legend from post parameters.
+    options = ['min_value', 'max_value', 'steps',
+               'min_color', 'max_color', 'too_low_color',
+               'too_high_color']
+
+    name = request.POST['name']
+    new_legend = {}
+    for option in options:
+        value = request.POST.get(option, None)
+        if value:
+            new_legend[option] = value
+
+    # Update session data with new obtained legend.
+    custom_legends = request.session.get(CUSTOM_LEGENDS, {})
+    custom_legends[name] = new_legend
+
+    request.session[CUSTOM_LEGENDS] = custom_legends
+
+    return HttpResponse('')
+
+
 """
 Map stuff
 """
